@@ -4,7 +4,13 @@ import logging
 
 from . import elements
 from .beam import Beam
-from .constraints import TargetDispersion, TargetGlobal, TargetPhasespace, TargetTwiss
+from .constraints import (
+    TargetDispersion,
+    TargetGlobal,
+    TargetPhasespace,
+    TargetTwiss,
+    TargetTwissSolution,
+)
 from .elements import *
 from .lattice import Lattice
 
@@ -13,11 +19,12 @@ __all__ = [
     "Lattice",
     "TargetPhasespace",
     "TargetTwiss",
+    "TargetTwissSolution",
     "TargetDispersion",
     "TargetGlobal",
 ]
 __all__.extend(elements.__all__)
 
-__version__ = "0.1.6"
+__version__ = "0.1.7"
 
 logger = logging.getLogger("pyaccelerator")
